#version 330

const int MAX_CLIP_PLANES = 6;

layout(location = 0) in uint objectId;
layout(location = 2) in vec3 position;

out VertexData {
    vec4 color;
} outData;

layout(std140) uniform GlobalMatrices {
    mat4 vp;
    mat4 model;
    mat4 proj;
    mat4 view;
};

uniform vec3 plane[MAX_CLIP_PLANES];
uniform vec3 planeOrigin[MAX_CLIP_PLANES];

void clip()
{
    for (int i = 0; i < MAX_CLIP_PLANES; i++)
    {
        gl_ClipDistance[i] = dot(plane[i], position - planeOrigin[i]);
    }
}

void main() {
    float r = float(objectId & 0xFFu) / 255f;
    float g = float((objectId & 0xFF00u) >> 8) / 255f;
    float b = float((objectId & 0xFF0000u) >> 16) / 255f;

    outData.color = vec4(r, g, b, 1);

    clip();
    gl_Position = vp * model * vec4(position, 1.0);
}
