#version 420 core

layout(location = 0) in uint objectId;
layout(location = 1) in int textureIndex;
layout(location = 2) in vec3 position;
layout(location = 3) in vec4 color;
layout(location = 4) in vec3 normal;
layout(location = 5) in vec2 texcoord;

out VertexData {
    flat uint objectId;
    flat int textureIndex;
    vec3 Normal;
    vec4 color;
    vec3 FragPos;
    vec2 texcoord;
    vec4 FragPosLightSpace0;
    vec4 FragPosLightSpace1;
    vec4 FragPosLightSpace2;
    vec4 VertexPosition;
} outData;


layout(std140, binding = 0) uniform GlobalMatrices {
    mat4 vp;
	mat4 model;
    mat4 proj;
	mat4 view;
};

uniform bool useColorFromObject = true;
uniform mat3 normalMat;
uniform mat4 lightSpaceMatrix0;
uniform mat4 lightSpaceMatrix1;
uniform mat4 lightSpaceMatrix2;

const int MAX_CLIP_PLANES = 6;

uniform vec3 plane[MAX_CLIP_PLANES];
uniform vec3 planeOrigin[MAX_CLIP_PLANES];

uniform samplerBuffer u_colors;

void clip()
{
    for (int i = 0; i < MAX_CLIP_PLANES; i++)
    {
        gl_ClipDistance[i] = dot(plane[i], position - planeOrigin[i]);
    }
}

void main() {
    vec4 objectColor = color;

    if (!useColorFromObject) {
        objectColor = texelFetch(u_colors, int(objectId));
    }

    outData.objectId = objectId;
    outData.textureIndex = textureIndex;
    outData.texcoord = texcoord;
    outData.color = objectColor;
    outData.VertexPosition = vec4(position, 1.0);
    outData.Normal = normalMat * normal;
    outData.FragPos = vec3(model * vec4(position, 1.0));

    outData.FragPosLightSpace0 = lightSpaceMatrix0 * vec4(outData.FragPos, 1.0);
    outData.FragPosLightSpace1 = lightSpaceMatrix1 * vec4(outData.FragPos, 1.0);
    outData.FragPosLightSpace2 = lightSpaceMatrix2 * vec4(outData.FragPos, 1.0);

    gl_Position = vp * model * vec4(position, 1.0);

    clip();
}
